@@ -1,5 +1,7 @@
 package OTRS::OPM::Analyzer::Role::Base;
 
+# ABSTRACT: interface for all checks
+
 use Moose::Role;
 
 requires 'check';
@@ -14,11 +16,15 @@ __END__
 
 =head1 NAME
 
-OTRS::OPM::Analyzer::Role::Base
+OTRS::OPM::Analyzer::Role::Base - interface for all checks
 
 =head1 VERSION
 
-version 0.01
+version 0.02
+
+=head1 INTERFACE
+
+All checks that implement this interface have to provide a I<check> method.
 
 =head1 AUTHOR
 
